@@ -32,7 +32,9 @@ gjamPriorTemplate <- function(formula, xdata, ydata, lo = NULL, hi = NULL){
     hiBeta <- .setLoHi(plist = hi, pmat = hiBeta, xnames, ynames)
   }
   
-  wna <- which( sapply(lo, is.na) | sapply(hi, is.na) )
+  
+  wna <- which( sapply(lo, is.na) )
+  wna <- c( wna, which( sapply(hi, is.na) ) )
   if(length(wna) > 0){
     rc <- columnSplit( names(wna), '_')
     rc <- rc[ rc[,2] %in% rownames(loBeta), ]             # reference level for factors will be absent
